nfv-tempest-plugin
==================================================

This project is a plugin to [OpenStack's Tempest](https://github.com/openstack/tempest) used to test NFV usecases.

### Installation

Please refer to the following [page](https://github.com/redhat-openstack/nfv-tempest-plugin/blob/master/docs/installation.md).

### Pre-requisites before running the plugin

Please refer to the following [page](https://github.com/redhat-openstack/nfv-tempest-plugin/blob/master/docs/tests_prerequisites_config.md).

### Tests and samples

For the list of tests with description, please refer to the following [page](https://github.com/redhat-openstack/nfv-tempest-plugin/blob/master/docs/tests.md).

For a sample external configuration file, please refer to the following [page](https://github.com/redhat-openstack/nfv-tempest-plugin/blob/master/docs/tests_config.yml.sample).

### Contributing

Please refer to the following [page](https://github.com/redhat-openstack/nfv-tempest-plugin/blob/master/docs/contribution.md).
